transfer

package
v0.0.0-...-836e728 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 6, 2022 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Package transfer provides Api methods to transfer tokens from the wallet to another wallet on same chain

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ApplyRoutes

func ApplyRoutes(r *gin.RouterGroup)

ApplyRoutes applies router to gin RouterGroup

Types

type TransferPayload

type TransferPayload struct {
	TransactionHash string `json:"hash"`
}

type TransferRequest

type TransferRequest struct {
	UserId string `json:"userId"`
	From   string `json:"from"`
	To     string `json:"to"`
	Amount int64  `json:"amount"`
}

Jump to