Documentation
¶
Overview ¶
Package transfer provides Api methods to transfer tokens from the wallet to another wallet on same chain
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ApplyRoutes ¶
func ApplyRoutes(r *gin.RouterGroup)
ApplyRoutes applies router to gin RouterGroup
Types ¶
type TransferPayload ¶
type TransferPayload struct {
TransactionHash string `json:"hash"`
}
Click to show internal directories.
Click to hide internal directories.